@@ -4,6 +4,10 @@
 #include <QMessageBox>
 #include "badgedata.h"
 #include <QDebug>
+#include <QLocale>
+#include <QtGui>
+
+
 
 DialogSearch::DialogSearch(QWidget *parent) :
     QDialog(parent)/*,
@@ -117,12 +121,20 @@ void DialogSearch::changeEvent(QEvent *e)
 QTime DialogSearch::totalHours(bool &ok)
 {
 
+
     if (this->exec() == QDialog::Accepted) {
         BadgeData data;
-        ok = true;
+        QLocale locale;
+        QString begin = pushButtonStart->valueText();
+        QString end = pushButtonEnd->valueText();
 
-        //qDebug() << "DATE " << QDate::fromString(pushButtonStart->valueText(),"dddd dd MMMM yyyy").toString() << endl;
-        return data.totalTime(QDate::fromString(pushButtonStart->valueText(), "dddd dd MMMM yyyy"), QDate::fromString(pushButtonEnd->valueText(), "dddd dd MMMM yyyy"));
+        begin.replace(QString("  "), QString(" "));
+        end.replace(QString("  "), QString(" "));
+
+        ok = true;
+        //qDebug() << "FORM " << locale.dateFormat(QLocale::LongFormat) << endl;
+        //qDebug() << "STR " << pushButtonStart->valueText() << " DATE " << QDate::fromString(begin, "dddd d MMMM yyyy").toString() << endl;
+        return data.totalTime(QDate::fromString(begin, "dddd d MMMM yyyy"), QDate::fromString(end, "dddd d MMMM yyyy"));
     }
     ok = false;
 
